#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MTHREE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MTHREE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mthree.hpp>

#endif
